@@ -3,6 +3,6 @@ from cerebralcortex.algorithms.ecg.ecg_signal_processing import process_ecg
 from cerebralcortex.algorithms.stress_prediction.stress_prediction import stress_prediction
 from cerebralcortex.algorithms.stress_prediction.stress_episodes import stress_episodes_estimation
 from cerebralcortex.algorithms.rr_intervals.rr_interval_feature_extraction import rr_interval_feature_extraction
-from cerebralcortex.algorithms.test.test import test_window
-__all__ = ["gps_clusters","process_ecg", "rr_interval_feature_extraction", "stress_prediciton", "test_window", "stress_episodes_estimation"]
+
+__all__ = ["gps_clusters","process_ecg", "rr_interval_feature_extraction", "stress_prediction", "stress_episodes_estimation"]
 
